Blob Blame History Raw
--- a/kernel/rh_taint.c	2019-05-25 14:06:27.474558423 -0700
+++ b/kernel/rh_taint.c	2019-05-25 14:25:53.471345832 -0700
@@ -2,12 +2,12 @@
 #include <linux/module.h>
 
 /*
  * The following functions are used by Red Hat to indicate to users that
  * hardware and drivers are unsupported, or have limited support in RHEL major
  * and minor releases.  These functions output loud warning messages to the end
  * user and should be USED WITH CAUTION.
  *
  * Any use of these functions _MUST_ be documented in the RHEL Release Notes,
  * and have approval of management.
  */
 
@@ -16,15 +16,15 @@
  * @msg: Hardware name, class, or type
  *
  * Called to mark a device, class of devices, or types of devices as not having
  * support in any RHEL minor release.  This does not TAINT the kernel.  Red Hat
  * will not fix bugs against this hardware in this minor release.  Red Hat may
  * declare support in a future major or minor update release.  This cannot be
  * used to mark drivers unsupported.
  */
 void mark_hardware_unsupported(const char *msg)
 {
 	/* Print one single message */
-	pr_crit("Warning: %s - this hardware has not undergone testing by Red Hat and might not be certified. Please consult https://hardware.redhat.com for certified hardware.\n", msg);
+	pr_crit("Warning: %s - this hardware has not undergone upstream testing. Please consult http://wiki.centos.org/FAQ for more information\n", msg);
 }
 EXPORT_SYMBOL(mark_hardware_unsupported);
 
@@ -35,12 +35,12 @@ EXPORT_SYMBOL(mark_hardware_unsupported)
  * Called to minimize the support status of a previously supported device in
  * a minor release.  This does not TAINT the kernel.  Marking hardware
  * deprecated is usually done in conjunction with the hardware vendor.  Future
  * RHEL major releases may not include this driver.  Driver updates and fixes
  * for this device will be limited to critical issues in future minor releases.
  */
 void mark_hardware_deprecated(const char *msg)
 {
-	pr_crit("Warning: %s - this hardware is not recommended for new deployments. It continues to be supported in this RHEL release, but it is likely to be removed in the next major release. Driver updates and fixes for this device will be limited to critical issues. Please contact Red Hat Support or your device's hardware vendor for additional information.\n", msg);
+	pr_crit("Warning: %s - this hardware is not recommended for new deployments. It continues to be supported in this CentOS Linux release, but it is likely to be removed in the next major release. Driver updates and fixes for this device will be limited to critical issues. Please contact CentOS Support or your device's hardware vendor for additional information.\n", msg);
 }
 EXPORT_SYMBOL(mark_hardware_deprecated);
 
@@ -50,9 +50,9 @@ EXPORT_SYMBOL(mark_hardware_deprecated);
  *
  * Called to minimize the support status of a new driver.  This does TAINT the
  * kernel.  Calling this function indicates that the driver or subsystem has
  * had limited testing and is not marked for full support within this RHEL
  * minor release.  The next RHEL minor release may contain full support for
  * this driver.  Red Hat does not guarantee that bugs reported against this
  * driver or subsystem will be resolved.
  */
 void mark_tech_preview(const char *msg, struct module *mod)
@@ -81,13 +81,13 @@ EXPORT_SYMBOL(mark_tech_preview);
  * mark_driver_unsupported - drivers that we know we don't want to support
  * @name: the name of the driver
  *
  * In some cases Red Hat has chosen to build a driver for internal QE
  * use. Use this function to mark those drivers as unsupported for
  * customers.
  */
 void mark_driver_unsupported(const char *name)
 {
-	pr_crit("Warning: %s - This driver has not undergone sufficient testing by Red Hat for this release and therefore cannot be used in production systems.\n",
+	pr_crit("Warning: %s - This driver has not undergone sufficient testing by CentOS for this release and therefore cannot be used in production systems.\n",
 	        name ? name : "kernel");
 }
 EXPORT_SYMBOL(mark_driver_unsupported);
@@ -2,12 +2,12 @@
 
 /*
- * The following functions are used by Red Hat to indicate to users that
- * hardware and drivers are unsupported, or have limited support in RHEL major
+ * The following functions are used by CentOS to indicate to users that
+ * hardware and drivers are unsupported, or have limited support in CentOS Linux major
  * and minor releases.  These functions output loud warning messages to the end
  * user and should be USED WITH CAUTION.
@@ -2,12 +2,12 @@
  * user and should be USED WITH CAUTION.
  *
- * Any use of these functions _MUST_ be documented in the RHEL Release Notes,
+ * Any use of these functions _MUST_ be documented in the CentOS Linux Release Notes,
  * and have approval of management.
  */
@@ -16,15 +16,15 @@
  *
  * Called to mark a device, class of devices, or types of devices as not having
- * support in any RHEL minor release.  This does not TAINT the kernel.  Red Hat
- * will not fix bugs against this hardware in this minor release.  Red Hat may
+ * support in any CentOS Linux minor release.  This does not TAINT the kernel. CentOS 
+ * will not fix bugs against this hardware in this minor release.  CentOS may
  * declare support in a future major or minor update release.  This cannot be
  * used to mark drivers unsupported.
@@ -35,12 +35,12 @@ EXPORT_SYMBOL(mark_hardware_unsupported)
  * a minor release.  This does not TAINT the kernel.  Marking hardware
  * deprecated is usually done in conjunction with the hardware vendor.  Future
- * RHEL major releases may not include this driver.  Driver updates and fixes
+ * CentOS Linux major releases may not include this driver.  Driver updates and fixes
  * for this device will be limited to critical issues in future minor releases.
  */
@@ -50,9 +50,9 @@ EXPORT_SYMBOL(mark_hardware_deprecated);
  * Called to minimize the support status of a new driver.  This does TAINT the
  * kernel.  Calling this function indicates that the driver or subsystem has
- * had limited testing and is not marked for full support within this RHEL
- * minor release.  The next RHEL minor release may contain full support for
- * this driver.  Red Hat does not guarantee that bugs reported against this
+ * had limited testing and is not marked for full support within this CentOS Linux
+ * minor release.  The next CentOS Linux minor release may contain full support for
+ * this driver.  CentOS does not guarantee that bugs reported against this
  * driver or subsystem will be resolved.
  */
@@ -81,13 +81,13 @@ EXPORT_SYMBOL(mark_tech_preview);
  * @name: the name of the driver
  *
- * In some cases Red Hat has chosen to build a driver for internal QE
+ * In some cases CentOS has chosen to build a driver for internal QE
  * use. Use this function to mark those drivers as unsupported for
  * customers.